function fig = eigtoolgui(fn_called,fig_no)

% function fig = eigtoolgui(fn_called,fig_no)
%
% This file actually creates the GUI. If called with no input arguments,
% the GUI will start and wait for the user to enter a matrix. A single
% argument (the matrix to use) can be passed, starting the GUI with that
% matrix. The more usual method of invoking the GUI is to call the
% function psa, which allows the use of additional options.
%
% fn_called    A matrix to default to
% fig_no       A number for the figure (optional)

% Version 2.1 (Mon Mar 16 00:24:49 CDT 2009)
% Copyright 2002 - 2009 by Tom Wright; maintained by Mark Embree (embree@rice.edu)
%
% The original version of EigTool was designed and built at Oxford 
% University during 2000-2002 by Thomas G. Wright in collaboration with 
% Mark Embree and Lloyd N. Trefethen.

% Check for preferences first. If they don't exist, create them.
if ~ispref('EigTool'),
  set_eigtool_prefs('default');
else
  ET_ver = getpref('EigTool','version');
  if ET_ver ~= 2.04,
    set_eigtool_prefs('update');
  end;
end;

% Update the usage count
usage_count = getpref('EigTool','usage_count');
setpref('EigTool','usage_count',usage_count+1);

%% Figure
if nargin<2, h0 = figure('visible','off'); fig_no = h0;
elseif fig_no>0, h0 = figure(fig_no,'visible','off');

% fig_no is negative if the figure already exists
% The correct number is then -fig_no
else
  h0 = -fig_no;
end; 

set(h0,'Units','points');
set(h0,'Color',[0.8 0.8 0.8]);
set(h0,'DoubleBuffer','on');
set(h0,'FileName','');
set(h0,'KeyPressFcn','dokeypress(gcbf)');
set(h0,'Name','EigTool');
set(h0,'PaperPosition',[18 180 576 432]);
set(h0,'PaperUnits','points');
%pos = get(0,'defaultFigurePosition'); pos(2) = pos(2)+pos(4)-478; pos(3) = 526; pos(4) = 478;
%set(h0,'Position',pos);

% If fig_no is positive, we have a new figure, so it needs to be positioned
if fig_no>0,
  set(h0,'Position',[210   62  526  478]);
else
% If it's negative, just need to make sure width & height are correct
  pos = get(h0,'pos');
  pos(3:4) = [526 478];
  set(h0,'pos',pos);
end;
%set(h0,'ResizeFcn','doresize(gcbf)');
set(h0,'Resize','off');
set(h0,'Tag','EigTOOL');
set(h0,'ToolBar','none');
set(h0,'MenuBar','none');
set(h0,'UserData',[]);
set(h0,'WindowButtonDownFcn','eigtool_switch_fn(''PsArea'');');
set(h0,'DefaultaxesCreateFcn','plotedit(gcbf,''promoteoverlay''); ');

%% Set the colourmap too
set_gui_colour_map(h0);

%% Menus
h1 = uimenu('Parent',h0, ...
	'Callback','filemenufcn(gcbf,''CreateCode'')', ...
	'Label','&File', ...
	'Tag','FileMenu');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''Import'')', ...
	'Label','&New Matrix...', ...
	'Tag','Import');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''FileSave'')', ...
	'Label','&Save Current State', ...
        'Separator','on', ...
	'Tag','FileSave');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''FileSaveAs'')', ...
	'Label','Save Current State &As...', ...
	'Tag','FileSaveAs');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','&Export...', ...
        'Separator','on', ...
	'Tag','Export');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ExportEWS'')', ...
	'Label','&Eigenvalues...', ...
	'Tag','ExportEws');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ExportMtx'')', ...
	'Label','&Original matrix...', ...
	'Tag','ExportMtx');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ExportSchur'')', ...
	'Label','&Schur factor...', ...
	'Tag','ExportSchur');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ExportPSA'')', ...
	'Label','&Pseudospectra data...', ...
	'Tag','ExportPSA');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''Print'')', ...
	'Label','&Printable Plot...', ...
	'Tag','FilePrint');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''Quit'')', ...
	'Label','&Quit', ...
        'Separator','on', ...
	'Tag','FileQuit');

h1 = uimenu('Parent',h0, ...
	'Label','&Extras', ...
	'Tag','ExtrasMenu');
h2 = uimenu('Parent',h1, ...
        'ForegroundColor',[.7 .25 .18], ...
	'Callback','et_download_mex', ...
	'Label','&Speeding up EigTool', ...
	'Tag','DownloadMEX');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''CreateCode'')', ...
	'Label','&Options Code for Printing', ...
        'Separator','on', ...
	'Tag','CreateCode');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''PrintOnly'')', ...
        'Label','Save for &Quick Print Creation...', ...
        'Tag','PrintOnly');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''Safety'');', ...
        'Label','Projection &Level...', ...
        'Separator','on', ...
        'Tag','Safety');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''Colour'');', ...
        'Label','&Colour', ...
        'Separator','on', ...
        'Tag','Colour');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''ThickLines'');', ...
        'Label','&Thick Lines', ...
        'Tag','ThickLines');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''UnequalLevels'');', ...
        'Label','&Arbitrary Levels', ...
        'Tag','UnequalLevels');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''FOVnpts'');', ...
        'Label','Accuracy of &FoV comp.', ...
        'Tag','FOVnpts');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''DisplayEWS'');', ...
        'Label','Display &Eigenvalues', ...
        'Separator','on', ...
        'Tag','DisplayEWS');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''DisplayPSA'');', ...
        'Label','Display &Pseudospectra', ...
        'Tag','DisplayPSA');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''ShowDimension'');', ...
        'Label','Display &Dimension', ...
        'Separator','on', ...
        'Tag','ShowDimension');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''ShowGrid'');', ...
        'Label','Display &Gridpoints', ...
        'Tag','ShowGrid');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''DisplayImagA'');', ...
        'Label','Display &Imaginary Axis', ...
        'Tag','DisplayImagA');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''DisplayUnitC'');', ...
        'Label','Display &Unit Circle', ...
        'Tag','DisplayUnitC');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''DisplayColourbar'');', ...
        'Label','Display Colour&Bar', ...
        'Separator','on', ...
        'Tag','DisplayColourbar');

h1 = uimenu('Parent',h0, ...
        'Enable','off', ...
	'Label','&ARPACK/eigs', ...
	'Tag','ARPACKMenu');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''ChooseP'')', ...
	'Label','Maximum &Subspace Size (p)...', ...
	'Tag','ChooseP');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''ChooseTol'')', ...
	'Label','Convergence &Tolerance (tol)...', ...
	'Tag','ChooseTol');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''ChooseMaxit'')', ...
	'Label','Maximum Number of &Restarts (maxit)...', ...
	'Tag','ChooseMaxit');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''ChooseV0'')', ...
	'Label','Starting &Vector (v0)...', ...
	'Tag','ChooseV0');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''ARPACK_auto_ax'')', ...
        'Checked','on', ...
	'Label','&Automatic axes', ...
        'Separator','on', ...
	'Tag','ARPACK_auto_ax');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','Show &Progress...', ...
        'Separator','on', ...
	'Tag','ARPACKProg');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ProgRVals'')', ...
        'Checked','on', ...
	'Label','&Ritz Values/Shifts', ...
	'Tag','ProgRVals');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ProgAllShifts'')', ...
	'Label','&All Shifts', ...
	'Tag','ProgAllShifts');
h3 = uimenu('Parent',h2, ...
	'Callback','eigtool_switch_fn(''ProgPSA'')', ...
	'Label','&Pseudospectra', ...
	'Tag','ProgPSA');

h1 = uimenu('Parent',h0, ...
        'Enable','on', ...
	'Label','&Transients', ...
	'Tag','TransientsMenu');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''MatrixPowers'')', ...
	'Label','Matrix &Powers', ...
	'Tag','MtxPowers');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''MatrixExp'')', ...
	'Label','Matrix &Exponentials', ...
	'Tag','MtxExp');
%h2 = uimenu('Parent',h1, ...
%	'Callback','', ...
%	'Label','&Lower Bound', ...
%        'Separator','on', ...
%	'Tag','TransientLB');
h3 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''TransientLB'')', ...
	'Label','&Compute a Bound', ...
        'Separator','on', ...
	'Tag','TransientLB');
h2 = uimenu('Parent',h1, ...
	'Callback','eigtool_switch_fn(''TransientBestLB'')', ...
	'Label','&Best Estimate Lower Bound', ...
	'Tag','TransientBestLB');
h3 = uimenu('Parent',h1, ...
	'Callback','type(''trans_lb_et_help''); disp(''Press <RETURN> to continue...'');', ...
	'Label','&Information', ...
        'Separator','on', ...
	'Tag','TransientLBInfo');

% Build the 'Numbers' menu
build_numbers_menu(h0);

mnu_h = uimenu('Parent',h0, ...
        'Label','&Demos', ...
        'Tag','DemosMenu');
h2 = uimenu('Parent',mnu_h, ...
        'Callback','eigtool_switch_fn(''FinerGrid'')', ...
        'Label','&Finer grid (slower)', ...
        'Tag','FinerGrid');
h1 =uimenu('Parent',mnu_h, ...
        'Callback','', ...
        'Label','&Dense matrices', ...
        'Separator','on', ...
        'Tag','DenseMatrices');
% Free letters in Dense submenu: JPQSY
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Airy', ...
        'Tag','DemoAiry');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoAiryS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','AiryPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoAiryC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','AiryCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Basor-Morrison', ...
        'Tag','DemoToeplitzPCS');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoToeplitzPCSS'')', ...
        'Label','Compute pseudospectra (&Faster: N=50)', ...
        'Tag','ToeplitzPCSPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoToeplitzPCSL'')', ...
        'Label','Compute pseudospectra (&Slower: N=100)', ...
        'Tag','ToeplitzPCSPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoToeplitzPCSC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','ToeplitzPCSCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Boeing &767', ...
        'Tag','DemoBoeing');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoBoeingL'')', ...
        'Label','Compute pseudospectra (&Unstable)', ...
        'Tag','BoeingPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoBoeingS'')', ...
        'Label','Compute pseudospectra (&Stable)', ...
        'Tag','BoeingPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoBoeingC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','BoeingCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Chebspec', ...
        'Tag','DemoChebspec');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoChebspecS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','ChebspecPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoChebspecC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','ChebspecCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Co&mpanion', ...
        'Tag','DemoCompanion');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoCompanionS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','CompanionPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoCompanionC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','CompanionCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Co&nvection-Diffusion', ...
        'Tag','DemoConvDiff');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoConvDiffS'')', ...
        'Label','Compute pseudospectra (&Faster: N=40)', ...
        'Tag','ConvDiffPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoConvDiffL'')', ...
        'Label','Compute pseudospectra (&Slower: N=100)', ...
        'Tag','ConvDiffPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoConvDiffC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','ConvDiffCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Davies', ...
        'Tag','DemoDavies');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoDaviesS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','DaviesPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoDaviesC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','DaviesCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','D&emmel', ...
        'Tag','DemoDemmel');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoDemmelS'')', ...
        'Label','Compute pseudospectra (&Faster: N=3)', ...
        'Tag','DemmelPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoDemmelL'')', ...
        'Label','Compute pseudospectra (&Slower: N=50)', ...
        'Tag','DemmelPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoDemmelC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','DemmelCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Frank', ...
        'Tag','DemoFrank');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoFrankS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','FrankPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoFrankC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','FrankCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Gallery &3', ...
        'Tag','DemoGallery3');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGallery3S'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','Gallery3PSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGallery3C'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','Gallery3Code');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Gallery &5', ...
        'Tag','DemoGallery5');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGallery5S'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','Gallery5PSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGallery5C'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','Gallery5Code');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Ga&uss-Seidel', ...
        'Tag','DemoGaussSeidel');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGaussSeidelN'')', ...
        'Label','Compute pseudospectra (&Classical)', ...
        'Tag','GaussSeidelPSAn');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGaussSeidelS'')', ...
        'Label','Compute pseudospectra (conv-diff, &Downwind)', ...
        'Tag','GaussSeidelPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGaussSeidelL'')', ...
        'Label','Compute pseudospectra (conv-diff, &Upwind)', ...
        'Tag','GaussSeidelPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGaussSeidelC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','GaussSeidelCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Goduno&v', ...
        'Tag','DemoGodunov');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGodunovS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','GodunovPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGodunovC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','GodunovCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Grcar', ...
        'Tag','DemoGrcar');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGrcarS'')', ...
        'Label','Compute pseudospectra (&Faster: N=50)', ...
        'Tag','GrcarPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGrcarL'')', ...
        'Label','Compute pseudospectra (&Slower: N=100)', ...
        'Tag','GrcarPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoGrcarC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','GrcarCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Hatano-Nelson', ...
        'Tag','DemoAnderson');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoAndersonS'')', ...
        'Label','Compute pseudospectra (&Faster: N=100)', ...
        'Tag','AndersonPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoAndersonL'')', ...
        'Label','Compute pseudospectra (&Slower: N=200)', ...
        'Tag','AndersonPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoAndersonC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','AndersonCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Kahan', ...
        'Tag','DemoKahan');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoKahanS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','KahanPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoKahanC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','KahanCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Landau', ...
        'Tag','DemoLandau');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoLandauS'')', ...
        'Label','Compute pseudospectra (&Faster: N=120)', ...
        'Tag','LandauPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoLandauL'')', ...
        'Label','Compute pseudospectra (&Slower: N=250)', ...
        'Tag','LandauPSAl');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoLandauC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','LandauCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Orr-Sommerfeld', ...
        'Tag','DemoOrrSommerfeld');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoOrrSommerfeldS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','OrrSommerfeldPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoOrrSommerfeldC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','OrrSommerfeldCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','&Random', ...
        'Tag','DemoRandom');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRandomS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','RandomPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRandomC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','RandomCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Random &Triangular', ...
        'Tag','DemoRandomTri');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRandomTriS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','RandomTriPSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRandomTriC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','RandomTriCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Riffle &Shuffle', ...
        'Tag','DemoRiffle');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRiffleS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','RifflePSAs');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoRiffleC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','RiffleCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Trans&ient', ...
        'Tag','DemoTransient');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoTransientS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','TransientPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoTransientC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','TransientCode');
h2 = uimenu('Parent',h1, ...
        'Callback','', ...
        'Label','Twisted Toeplit&z', ...
        'Tag','DemoTwisted');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoTwistedS'')', ...
        'Label','&Compute pseudospectra', ...
        'Tag','TwistedPSA');
h3 = uimenu('Parent',h2, ...
        'Callback','eigtool_switch_fn(''DemoTwistedC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','TwistedCode');
h2 = uimenu('Parent',mnu_h, ...
        'Callback','', ...
        'Label','&Sparse matrices', ...
        'Tag','');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Dielectric waveguide', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoDwaveS'')', ...
        'Label','&ARPACK/eigs computation (N=2048)', ...
        'Tag','DwavePSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoDwaveC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','DwaveCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Convection Diffusion (sparse)', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseCDS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=1600)', ...
        'Tag','SparseCDPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseCDL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=3600)', ...
        'Tag','SparseCDPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseCDC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','SparseCDCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Elliptic PDE', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoPDES'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=900)', ...
        'Tag','PDEPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoPDEL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=2961)', ...
        'Tag','PDEPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoPDEC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','PDECode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Markov Chain', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoMarkovS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=465)', ...
        'Tag','MarkovPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoMarkovL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=5050)', ...
        'Tag','MarkovPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoMarkovC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','MarkovCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Olmstead', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoOlmsteadS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=500)', ...
        'Tag','OlmsteadPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoOlmsteadL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=1000)', ...
        'Tag','OlmsteadPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoOlmsteadC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','OlmsteadCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','R-D &Brusselator', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoRDBS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=800)', ...
        'Tag','RDBPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoRDBL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=3200)', ...
        'Tag','RDBPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoRDBC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','RDBCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Random (sparse)', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseRandS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=30,000)', ...
        'Tag','SparseRandPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseRandL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=100,000)', ...
        'Tag','SparseRandPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSparseRandC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','SparseRandCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Skew Laplacian (3D)', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSkewLapS'')', ...
        'Label','&ARPACK/eigs computation (N=6859)', ...
        'Tag','SkewLapPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSkewLapC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','SkewLapCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','S&UPG', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSUPGS'')', ...
        'Label','&ARPACK/eigs computation (N=900)', ...
        'Tag','SparseRandPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoSUPGC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','SUPGCode');
h3 = uimenu('Parent',h2, ...
        'Callback','', ...
        'Label','&Tolosa', ...
        'Tag','');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoTolosaS'')', ...
        'Label','ARPACK/eigs computation (&Faster: N=1090)', ...
        'Tag','TolosaPSAs');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoTolosaL'')', ...
        'Label','ARPACK/eigs computation (&Slower: N=4000)', ...
        'Tag','TolosaPSAl');
h4 = uimenu('Parent',h3, ...
        'Callback','eigtool_switch_fn(''DemoTolosaC'')', ...
        'Label','&Description and code', ...
        'Separator','on', ...
        'Tag','TolosaCode');

h1 = uimenu('Parent',h0, ...
	'Callback','winmenu(gcbo)', ...
	'Label','&Window', ...
	'Tag','WindowMenu');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');
h2 = uimenu('Parent',h1, ...
	'Callback','', ...
	'Label','blank', ...
	'Tag','');

h1 = uimenu('Parent',h0, ...
	'Callback','', ...
	'Label','&Help', ...
	'Tag','HelpMenu');
%        'Callback','web(''http://www.comlab.ox.ac.uk/pseudospectra/eigtool/documentation/'');', ...
%        'Callback','web([''file://'' which(''eigtool_docs.html'')]);', ...
h2 = uimenu('Parent',h1, ...
        'ForegroundColor',[.7 .25 .18], ...
	'Callback','et_download_mex', ...
	'Label','&Speeding up EigTool', ...
	'Tag','DownloadMEX');
h2 = uimenu('Parent',h1, ...
        'Callback','web([''file://'' which(''eigtool_docs.html'')]);', ...
        'Label','EigTool &Documentation', ...
        'Separator','on', ...
        'Tag','Documentation');
h2 = uimenu('Parent',h1, ...
        'Callback','eigtool_switch_fn(''PSADEMO'');', ...
        'Label','Pseudospectra &Tutorial', ...
        'Tag','PsaTutorial');
h2 = uimenu('Parent',h1, ...
        'Callback','web(''http://www.comlab.ox.ac.uk/pseudospectra/eigtool/'');', ...
        'Label','EigTool &Homepage', ...
        'Separator','on', ...
        'Tag','EigToolHome');
h2 = uimenu('Parent',h1, ...
        'Callback','web(''http://www.comlab.ox.ac.uk/pseudospectra/'');', ...
        'Label','Pseudospectra &Gateway', ...
        'Tag','PsaInfo');

h1 = uimenu('Parent',h0, ...
	'HandleVisibility','off', ...
	'Tag','ScribeFigObjStorage', ...
	'Visible','off');

%% This cell array contains all the messages the GUI can display
the_messages = { ...
  'EigTool: left button to zoom in, right button to zoom out',
  'Press the Go! button to compute on the new axes...',
  'Press the Go! button to compute on the new grid...',
  'Press the Go! button to compute with new projection level...',
  'Please click on an eigenvalue...',
  'More Info: http://www.comlab.ox.ac.uk/pseudospectra/ (click)',
  'Click close to return to EigTool...',
  'Automatic appropriate levels',
  'Begin computing',
  'Compute the numerical range',
  'Revert to original plot',
  'Display an eigenmode and eigenvalue condition number',
  'Display a pseudomode and corresponding resolvent norm',
  'Create a 3D surface plot of the pseudospectra',
  'Exit EigTool',
  'The amount of projection used: Inf = none',
  'Define appropriate levels automatically',
  'Smallest contour levels shown (log base 10)',
  'Level spacing: see Extras menu for abritrary spacing',
  'Stop the current computation',
  'Coloured or black and white lines',
  'Thick or thin lines',
  'Equivalent to axis equal',
  'This number is the minimum x value.',
  'This number is the maximum x value.',
  'This number is the minimum y value.',
  'This number is the minimum y value.',
  'Press the Go! button to compute with the new scale...',
  'Please click on a point...',
  'EigTool: a graphical tool for nonsymmetric eigenproblems',
  'Press the Go! button to compute with the new parameters...',
  'Pause the current computation',
  'Press the Go! button to compute with the new method...',
  'Display a Ritz vector and its residual',
  'Press Pause to change display options',
  'Press Resume to continue',
  'Change ARPACK parameters and press Go! to compute...',
  'EigTool: please wait...',
  'Press the Go! button to recompute...'
  'Please click on a point as the basis for the bound...',
  };

%% Frames
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[16.941176470588   12.705882352941   203.294117647059   122.823529411765], ...
	'Style','frame', ...
	'Tag','Frame1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[338.823529411765   12.705882352941   173.647058823529   122.823529411765], ...
	'String','testy1', ...
	'Style','frame', ...
	'Tag','Frame2');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[410.8235294117647 144 101.6470588235294 38.11764705882353], ...
	'Style','frame', ...
	'Tag','Frame3');

h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[12.705882352941   444.705882352941   499.764705882353   25.411764705882], ...
	'Style','frame', ...
	'Tag','MessageFrame', ...
        'UserData',the_messages);
%h1 = uicontrol('Parent',h0, ...
%	'Units','points', ...
%	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
%	'ListboxTop',0, ...
%	'Position',[228.7058823529412 93.17647058823529 101.6470588235294 42.35294117647059], ...
%	'Style','frame', ...
%	'Tag','Frame5');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[410.823529411765   190.588235294118   101.647058823529   245.647058823529], ...
	'Style','frame', ...
	'Tag','Frame6');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'ListboxTop',0, ...
	'Position',[228.705882352941   12.705882352941   101.647058823529   123], ...
	'Style','frame', ...
	'Tag','Frame7');

%% Title
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'FontSize',14, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[16.94117647058824 447 491.2941176470588 19], ...
	'String',the_messages{1}, ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','MessageText');

%% Buttons
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0 0.921 0.38375], ...
	'Callback','eigtool_switch_fn(''Redraw'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[423.529 397.270 77.929 24.564], ...
	'String','Go!', ...
	'Tag','RedrawPlot', ...
        'TooltipString',the_messages{9});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 .86 .18], ...
	'Callback','eigtool_switch_fn(''Pause'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[423.529 365.082 77.929 24.564], ...
	'String','Pause', ...
	'Tag','Pause', ...
        'TooltipString',the_messages{32});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''FieldOfVals'');', ...
	'Enable','off', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[423.5294117647059   332.894   77.92941176470588  25.41176470588235], ...
	'String','Field of Vals', ...
	'Style','checkbox', ...
	'Tag','FieldOfVals', ...
	'Value',0, ...
        'TooltipString',the_messages{10});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
 	'BackgroundColor',[0.702 0.704 0.702], ...  % mpe: replaces %  	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''EwCond'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[423.529  300.7058 77.929 25.411], ...
	'String','Mode+Cond.No', ...
	'Tag','EwCond', ...
        'TooltipString',the_messages{12});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
 	'BackgroundColor',[0.702 0.704 0.702], ...  % mpe: replaces %  	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''PseudoMode'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[423.529 268.517 77.929 25.411], ...
	'String','Pmode+epsilon', ...
	'Tag','PseudoMode', ...
        'TooltipString',the_messages{13});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
 	'BackgroundColor',[.702 0.704 0.702], ...  % mpe: replaces %  	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''Print3D'');', ...
	'ListboxTop',0, ...
	'Position',[423.529 235.482 77.929 25.411], ...
	'String','3D Plot', ...
	'Tag','Plot3D', ...
        'TooltipString',the_messages{14});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
 	'BackgroundColor',[0.702 0.704 0.702], ...  % mpe: replaces %  	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''Quit'');', ...
	'ListboxTop',0, ...
	'Position',[423.529 203.294 77.929 25.411], ...
	'String','Quit', ...
	'Tag','Quit', ...
        'TooltipString',the_messages{15});

%% Axes
h1 = axes('Parent',h0, ...
	'Units','points', ...
        'Box','on', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'CreateFcn','plotedit(gcbf,''promoteoverlay''); ', ...
	'HitTest','off', ...
	'NextPlot','replacechildren', ...
	'PlotBoxAspectRatioMode','manual', ...
	'Position',[38 169 285 255], ...
	'Tag','MainAxes', ...
	'Visible','off', ...
	'WarpToFill','off', ...
	'WarpToFillMode','manual', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4984126984126984 -0.06349206349206349 9.160254037844386], ...
	'Tag','Axes1Text4', ...
	'VerticalAlignment','cap');
set(get(h2,'Parent'),'XLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
        'fontsize',10, ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.07619047619047609 0.4984126984126983 9.160254037844386], ...
	'Rotation',90, ...
        'String','', ...
	'Tag','MainAxYLabel', ...
	'VerticalAlignment','baseline');
set(get(h2,'Parent'),'YLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','right', ...
	'Position',[-0.1999999999999999 1.180952380952381 9.160254037844386], ...
	'Tag','Axes1Text2', ...
	'Visible','off');
set(get(h2,'Parent'),'ZLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.49841269841270   1.01587301587302   9.16025403784439], ...
	'Tag','Axes1Text1', ...
	'VerticalAlignment','bottom');
set(get(h2,'Parent'),'Title',h2);
h1 = axes('Parent',h0, ...
	'Units','points', ...
	'Box','on', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'CreateFcn','plotedit(gcbf,''promoteoverlay''); ', ...
	'NextPlot','replacechildren', ...
	'Position',[338.8235294117647 160.9411764705882 32.18823529411765 267.6705882352941], ...
	'Tag','MyColourBar', ...
	'Visible','off', ...
	'XColor',[0 0 0], ...
	'XLimMode','manual', ...
	'XTickMode','manual', ...
	'YAxisLocation','right', ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4864864864864877 -0.02222222222222214 9.160254037844386], ...
	'Tag','Axes2Text4', ...
	'VerticalAlignment','cap');
set(get(h2,'Parent'),'XLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[1.594594594594595 0.4952380952380953 9.160254037844386], ...
	'Rotation',90, ...
	'Tag','Axes2Text3', ...
	'VerticalAlignment','cap');
set(get(h2,'Parent'),'YLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','right', ...
	'Position',[-10.83783783783784 1.180952380952381 9.160254037844386], ...
	'Tag','Axes2Text2', ...
	'Visible','off');
set(get(h2,'Parent'),'ZLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4864864864864877 1.015873015873016 9.160254037844386], ...
	'Tag','Axes2Text1', ...
	'VerticalAlignment','bottom');
set(get(h2,'Parent'),'Title',h2);

%% Mesh size
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'FontWeight','demi', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[414 165 96 12.7], ...
	'String','Mesh:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText8');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''MeshSize'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[470.117647058824   148.235294117647   31  22], ...  % mpe edit
	'Style','edit', ...
	'Tag','meshsize');
%	'Position',[470.117647058824   148.235294117647   29.647058823529   16.941176470588], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[415.058823529412   149.5   50.823529411765   15.247058823529], ... % mpe edit % mpe edit
	'String','Grid Size:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText6');
%	'Position',[415.058823529412   148.235294117647   50.823529411765   15.247058823529], ...

%% Scale control
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'FontWeight','demi', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[21.176470588235   118.588235294118   101.647058823529   12.705882352941], ...
	'String','Figure Axes:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText8');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''ScaleEqual'');', ...
	'Enable','off', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[33.88235294117647 93.17647058823529 114.3529411764706 20.32941176470588], ...
	'String','Scale Equal', ...
	'Style','checkbox', ...
	'Tag','ScaleEqual', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EditXmin'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[63.5 45 50 21], ...  % mpe edit
	'Style','edit', ...
	'Tag','xmin');
%	'Position',[63.52941176470588 46.58823529411764 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EditXmax'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[165.1764705882353 45 50 21], ...  % mpe edit
	'Style','edit', ...
	'Tag','xmax');
%	'Position',[165.1764705882353 46.58823529411764 49.97647058823529 17.78823529411765], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EditYmin'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[114.3529411764706 20 50 21], ...  % mpe edit
	'Style','edit', ...
	'Tag','ymin');
%	'Position',[114.3529411764706 25.41176470588235 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EditYmax'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[114.3529411764706 67 50 21], ...
	'Style','edit', ...
	'Tag','ymax');
%	'Position',[114.3529411764706 67.76470588235294 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[21.17647058823529 46 39.81176470588235 15.24705882352941], ... % mpe edit
	'String','X min:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText1');
%	'Position',[21.17647058823529 46.58823529411764 39.81176470588235 15.24705882352941], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[122.8235294117647 46 39.81176470588235 16.94117647058824], ... % mpe edit
	'String','X max:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText2');
%	'Position',[122.8235294117647 46.58823529411764 39.81176470588235 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[72 21 39.81176470588235 15.24705882352941], ... % mpe edit
	'String','Y min:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText3');
%	'Position',[72 25.41176470588235 39.81176470588235 15.24705882352941], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[72 68 39.81176470588235 15.24705882352941], ...
	'String','Y max:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText5');
%	'Position',[72 67.76470588235294 39.81176470588235 15.24705882352941], ...

%% ARPACK/eigs
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'FontWeight','demi', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[232.941176470588   118.588235294118   82   12.705882352941], ...
	'String','Direct/Iterative:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText8');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''Direct'');', ...
	'Enable','on', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[235   95   95   22.32941], ... % mpe edit
	'Style','radio', ...
        'String','Direct', ...
	'Tag','Direct', ...
        'Value',1);
%	'Position',[241.411   95   84   20.32941], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''Iterative'');', ...
	'Enable','on', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[235   73   95   22.32941], ... % mpe edit
	'Style','radio', ...
        'String','ARPACK/eigs', ...
	'Tag','Iterative', ...
        'Value',0);
%	'Position',[241.411   70   84   22.32941], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[240 52   53   12.705882352941], ...  % mpe edit
	'String','No. eigs (k):', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText100');
%	'Position',[241.4117   48   53   12.705882352941], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''ARPACK_k'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[295   46.5882   30   22], ...  % mpe edit
        'String','', ...
	'Style','edit', ...
	'Tag','ARPACK_k');
%	'Position',[295   46.5882   30   16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''Which'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[241.411   21.176   84   20.32941], ...
	'Style','popupmenu', ...
        'String','Large Mod.|Small Mod.|Large Real|Small Real|Large Imag.|Small Imag.', ... % mpe: replaces % 'String','Large Mod.|Small Mod.|Large Real|Small Real|Large Imag.|Small Imag.|Large Alg.|Small Alg.|Both Ends', ...
        'Userdata',{'LM','SM','LR','SR','LI','SI'}, ... % mpe: replaces % 'Userdata',{'LM','SM','LR','SR','LI','SI','LA','SA','BE'}, ...
	'Tag','Which');

%% Contour levels
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.702 0.704 0.702], ...  % mpe: replaces %   'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'Callback','eigtool_switch_fn(''AutoLev'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[354.917647058824   93.176470588235   102.494117647059   21.176470588235], ...
	'String','Smart  levels', ...
	'Tag','AutoLev', ...
        'TooltipString',the_messages{17});
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'FontWeight','demi', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[343.058823529412   118.588235294118   148.235294117647   12.705882352941], ...
	'String','Contour Levels:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText9');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EpsLevMax'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[445 66 50 21.5], ... % mpe edit
	'Style','edit', ...
	'Tag','lastlev');
%	'Position',[444.7058823529412 67.76470588235294 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EpsLevMin'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[445 42 50 21.5], ... % mpe edit
	'Style','edit', ...
	'Tag','firstlev');
%	'Position',[444.7058823529412 46.58823529411764 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','eigtool_switch_fn(''EpsLevPts'');', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[445 18 50 21.5], ... % mpe edit
	'Style','edit', ...
	'Tag','nolev', ...
        'TooltipString',the_messages{19});
%	'Position',[444.7058823529412 25.41176470588235 49.97647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[347.2941176470588 67 93.17647058823529 16.94117647058824], ... % mpe edit
	'String','log10(largest):', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText7');
%	'Position',[347.2941176470588 67.76470588235294 93.17647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[347.2941176470588 43 93.17647058823529 16.94117647058824], ... % mpe edit
	'String','log10(smallest):', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText7');
%	'Position',[347.2941176470588 46.58823529411764 93.17647058823529 16.94117647058824], ...
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.701960784313725 0.701960784313725 0.701960784313725], ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[347.2941176470588 19 93.17647058823529 16.94117647058824], ... % mpe edit
	'String','Step size:', ...
        'Enable','inactive', ...
	'Style','text', ...
	'Tag','StaticText7');
%	'Position',[347.2941176470588 25.41176470588235 93.17647058823529 16.94117647058824], ...

SMALL_GUI = getpref('EigTool','SMALL_GUI');

% Make the GUI smaller if necessary
if SMALL_GUI,
  shrink_gui(h0,0.86);
  h_pos = get(h0,'pos');
  h_pos(1:2) = [26  6];
  set(h0,'Position',h_pos);
else
  set(h0,'Position',[210   62  526  478]);
end;
%movegui(h0,'onscreen');
set(h0,'Visible','on');

if nargout > 0, fig = h0; end;

