function plot_pseudospectra(A,B,epsilon,opts)

if ~isfield(opts,'linestyle')
  opts.linestyle = '-';
end

xmin = opts.bounds(1);
xmax = opts.bounds(2);
ymin = opts.bounds(3);
ymax = opts.bounds(4);

% Sample the pencil pseudospectrum (AV,V)
r_zs = linspace(xmin,xmax,opts.npts );
i_zs = linspace(ymin,ymax,opts.npts );

for ii_r = 1:length(r_zs)
  for ii_i = 1:length(i_zs)
    z = r_zs(ii_r) + 1i*i_zs(ii_i);
    vals(ii_i,ii_r) = min(svd(z*B-A,0));
  end
end

figure(opts.fig)
contour(r_zs, i_zs, log10(vals), [log10(epsilon) log10(epsilon)], 'LineWidth', 3, 'LineStyle', opts.linestyle, 'Color', opts.Color_Epsilon);

if isfield(opts, 'contours')
  vals(1,1) = 0.5*10^min(opts.contours);
  vals(1,2) = 2*10^max(opts.contours);

  [con,con_hdl] = contour(r_zs, i_zs, log10(vals), opts.contours, 'LineWidth', 2, 'LineStyle', opts.linestyle);
  
  
  if isfield(opts, 'colormap')
    colormap(opts.colormap)
  end

  colorbar('off')
  if isfield(opts, 'colormap_off')
    % nop
  else
    add_mycolourbar(con,opts.fig,opts.contours);
  end
end


